E CVS: apps/e raster

2006-12-05 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : raster
Project : e17
Module  : apps/e

Dir : e17/apps/e/src/bin


Modified Files:
e_fm.h e_fm_prop.c e_utils.c e_utils.h e_widget_fsel.c 


Log Message:


working on file properties dialog.

===
RCS file: /cvs/e/e17/apps/e/src/bin/e_fm.h,v
retrieving revision 1.34
retrieving revision 1.35
diff -u -3 -r1.34 -r1.35
--- e_fm.h  4 Dec 2006 12:14:17 -   1.34
+++ e_fm.h  5 Dec 2006 14:28:48 -   1.35
@@ -14,6 +14,7 @@
E_FM2_VIEW_MODE_CUSTOM_SMART_GRID_ICONS, /* icons go anywhere u drop them 
but try align to icons nearby */
E_FM2_VIEW_MODE_LIST /* vertical fileselector list */
 } E_Fm2_View_Mode;
+
 typedef enum _E_Fm2_Menu_Flags
 {
E_FM2_MENU_NO_REFRESH   = (1  0),
===
RCS file: /cvs/e/e17/apps/e/src/bin/e_fm_prop.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.4 -r1.5
--- ewl_text.c  5 Dec 2006 06:26:33 -   1.4
+++ ewl_text.c  5 Dec 2006 14:49:46 -   1.5
@@ -116,7 +116,6 @@
 
printf(Insert 'The first bunch of text\\n'\n);
ewl_text_text_insert(EWL_TEXT(o), The first bunch of text\n, 0); /* 
24 */
-   return 1;
 
printf(Cursor position\n);
ewl_text_cursor_position_set(EWL_TEXT(o), 10);



-
Take Surveys. Earn Cash. Influence the Future of IT
Join SourceForge.net's Techsay panel and you'll get the chance to share your
opinions on IT  business topics through brief surveys - and earn cash
http://www.techsay.com/default.php?page=join.phpp=sourceforgeCID=DEVDEV
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ewl ningerso

2006-12-05 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : ningerso
Project : e17
Module  : libs/ewl

Dir : e17/libs/ewl/src/lib


Modified Files:
ewl_dnd.c 


Log Message:
Request the type for the dnd data request callback.

===
RCS file: /cvs/e/e17/libs/ewl/src/lib/ewl_dnd.c,v
retrieving revision 1.36
retrieving revision 1.37
diff -u -3 -r1.36 -r1.37
--- ewl_dnd.c   5 Dec 2006 06:26:34 -   1.36
+++ ewl_dnd.c   5 Dec 2006 14:50:41 -   1.37
@@ -52,6 +52,7 @@
EWL_CALLBACK_DND_LEAVE = ewl_callback_type_add();
EWL_CALLBACK_DND_DROP = ewl_callback_type_add();
EWL_CALLBACK_DND_DATA_RECEIVED = ewl_callback_type_add();
+   EWL_CALLBACK_DND_DATA_REQUEST = ewl_callback_type_add();
 
ewl_dnd_widget = NULL;
ewl_dnd_status = 0;



-
Take Surveys. Earn Cash. Influence the Future of IT
Join SourceForge.net's Techsay panel and you'll get the chance to share your
opinions on IT  business topics through brief surveys - and earn cash
http://www.techsay.com/default.php?page=join.phpp=sourceforgeCID=DEVDEV
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore mej

2006-12-05 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : mej
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore


Modified Files:
ecore.spec.in 


Log Message:
Tue Dec  5 16:50:38 2006Michael Jennings (mej)

Fix spec file and add directfb support.
--

===
RCS file: /cvs/e/e17/libs/ecore/ecore.spec.in,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -3 -r1.15 -r1.16
--- ecore.spec.in   28 Oct 2006 11:41:53 -  1.15
+++ ecore.spec.in   5 Dec 2006 21:50:39 -   1.16
@@ -16,16 +16,19 @@
 %endif
 
 ## disabled features
-%bcond_withlib_ecore_fb
 
-## not setup yet...
 ## enabled features
 ##%bcond_without module_engine_software_x11
+%bcond_without lib_ecore_fb
+%bcond_without lib_ecore_directfb
 
 
 # This just keeps a missing doxygen from killing the build.
 %define _missing_doc_files_terminate_build 0
 
+%define ac_with_lib_ecore_fb  
--%{?with_lib_ecore_fb:en}%{!?with_lib_ecore_fb:dis}able-ecore-fb
+%define ac_with_lib_ecore_directfb 
--%{?with_lib_ecore_directfb:en}%{!?with_lib_ecore_directfb:dis}able-ecore-dfb
+
 Summary: Enlightened Core X interface library
 Name: @PACKAGE@
 Version: @VERSION@
@@ -53,9 +56,9 @@
 Group: Development/Libraries
 Requires: %{name} = %{version}
 Requires: openssl-devel, evas-devel, eet-devel
-Requires: ecore-con, ecore-config, ecore-dbus, ecore-desktop, ecore-evas, 
ecore-file, ecore-ipc, ecore-job, ecore-txt, ecore-x
-##removed fb
-##Requires: ecore-con, ecore-config, ecore-dbus, ecore-desktop, ecore-evas, 
ecore-fb, ecore-file, ecore-ipc, ecore-job, ecore-txt, ecore-x
+Requires: ecore-con, ecore-config, ecore-dbus, ecore-desktop,
+Requires: ecore-evas, ecore-file, ecore-ipc, ecore-job, ecore-txt
+Requires: ecore-x %{?with_lib_ecore_fb:ecore-fb} 
%{?with_lib_ecore_directfb:ecore-directfb}
 
 %description devel
 Ecore development files
@@ -100,6 +103,15 @@
 %description desktop
 Ecore freedesktop.org .desktop, icon, menu parsing Library
 
+%if %{with lib_ecore_directfb}
+%package directfb
+Summary: Ecore DirectFB system functions
+Group: Development/Libraries
+Requires: %{name} = %{version}
+%description directfb
+Ecore DirectFB system functions
+%endif
+
 %package evas
 Summary: Ecore Evas Wrapper Library
 Group: Development/Libraries
@@ -115,9 +127,6 @@
 Requires: %{name} = %{version}
 %description fb
 Ecore frame buffer system functions
-%define ac_with_lib_ecore_fb --enable-ecore-fb
-%else
-%define ac_with_lib_ecore_fb --disable-ecore-fb
 %endif
 
 %package file
@@ -160,8 +169,6 @@
 %description x
 Ecore functions for dealing with the X Windows System
 
-
-
 %prep
 %setup -q -n %{name}-%{version}
 
@@ -169,8 +176,7 @@
 CFLAGS=-I/usr/kerberos/include -I/usr/X11R6/include/X11/extensions
 LDFLAGS=-L/usr/kerberos/lib -L/usr/X11R6/%{_lib}
 export CFLAGS LDFLAGS
-%{configure} --prefix=%{_prefix} --disable-ecore-dfb \
-   %{ac_with_lib_ecore_fb}
+%{configure} --prefix=%{_prefix} %{?ac_with_lib_ecore_fb} 
%{?ac_with_lib_ecore_directfb}
 %{__make} %{?_smp_mflags} %{?mflags}
 
 %install
@@ -220,6 +226,12 @@
 %files desktop
 %defattr(-, root, root)
 %{_libdir}/libecore_desktop.so.*
+
+%if %{with lib_ecore_directfb}
+%files directfb
+%defattr(-, root, root)
+%{_libdir}/libecore_directfb.so.*
+%endif
 
 %files evas
 %defattr(-, root, root)



-
Take Surveys. Earn Cash. Influence the Future of IT
Join SourceForge.net's Techsay panel and you'll get the chance to share your
opinions on IT  business topics through brief surveys - and earn cash
http://www.techsay.com/default.php?page=join.phpp=sourceforgeCID=DEVDEV
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs
diff -u -3 -r1.1 -r1.2
--- e_fm_prop.c 4 Dec 2006 12:14:17 -   1.1
+++ e_fm_prop.c 5 Dec 2006 14:28:48 -   1.2
@@ -6,20 +6,20 @@
 /* FIXME:
  * 
  * basic -
  * * show file
  * * show size
  * * show modified date
  * * show permissions
  * * show preview
  * * show icon
  * * show symlink/fifo/socket/etc. status
  * * show broken link status
  * * change icon for mime type
  * * change icon for just this file
- * * change permissions
+ * * change permissions (others read, others write)
  * 
  * advanced (extra) -
- * * change app to open THIS file with
  * * show access date
  * * show change date
  * * show pseudolink status
@@ -29,6 +29,7 @@
  * * show mount status
  * * show link destination (if symlink or link)
  * * change link destination
+ * * change app to open THIS file with (or dir)
  * 
  */
 
@@ -46,6 +47,12 @@
 {
E_Fm2_Icon_Info *fi;
/*- BASIC -*/
+   char *file;
+   char *size;
+   char *mod_date;
+   char *mime;
+   int others_read;
+   int others_write;
/*- ADVANCED -*/
 };
 
@@ -77,7 +84,15 @@
 static void
 _fill_data(E_Config_Dialog_Data *cfdata, E_Fm2_Icon_Info *fi)
 {
+   char buf[4096];
+   
cfdata-fi = fi;
+   if (fi-file) cfdata-file = strdup(fi-file);
+   cfdata-size = e_util_size_string_get(fi-statinfo.st_size);
+   cfdata-mod_date = e_util_file_time_get(fi-statinfo.st_mtime);
+   if (fi-mime) cfdata-mime = strdup(fi-mime);
+   if (fi-statinfo.st_mode  S_IROTH) cfdata-others_read = 1;
+   if (fi-statinfo.st_mode  S_IWOTH) cfdata-others_write = 1;
 }
 
 static void *
@@ -98,6 +113,10 @@
 _free_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
 {
/* Free the cfdata */
+   E_FREE(cfdata-file);
+   E_FREE(cfdata-size);
+   E_FREE(cfdata-mod_date);
+   E_FREE(cfdata-mime);
free(cfdata);
 }
 
@@ -119,7 +138,7 @@
 _basic_create_widgets(E_Config_Dialog *cfd, Evas *evas, E_Config_Dialog_Data 
*cfdata)
 {
/* generate the core widget layout for a basic dialog */
-   Evas_Object *o, *ot, *ob;
+   Evas_Object *o, *ot, *ob, *of;
char buf[4096];

snprintf(buf, sizeof(buf), %s/%s, 
@@ -130,18 +149,39 @@

ob = e_widget_label_add(evas, _(File:));
e_widget_table_object_append(ot, ob, 0, 0, 1, 1, 1, 0, 1, 0);
-   ob = e_widget_entry_add(evas, NULL);
-   e_widget_min_size_set(ob, 80, -1);
+   ob = e_widget_entry_add(evas, (cfdata-file));
+   e_widget_min_size_set(ob, 140, -1);
e_widget_entry_readonly_set(ob, 1);
e_widget_table_object_append(ot, ob, 1, 0, 1, 1, 1, 0, 1, 0);

ob = e_widget_label_add(evas, _(Size:));
e_widget_table_object_append(ot, ob, 0, 1, 1, 1, 1, 0, 1, 0);
-   ob = e_widget_entry_add(evas, NULL);
-   e_widget_min_size_set(ob, 80, -1);
+   ob = e_widget_entry_add(evas, (cfdata-size));
+   e_widget_min_size_set(ob, 140, -1);
e_widget_entry_readonly_set(ob, 1);
e_widget_table_object_append(ot, ob, 1, 1, 1, 1, 1, 0, 1, 0);
 
+   ob = e_widget_label_add(evas, _(Last Modified:));
+   e_widget_table_object_append(ot, ob, 0, 2, 1, 1, 1, 0, 1, 0);
+   ob = e_widget_entry_add(evas, (cfdata-mod_date));
+   e_widget_min_size_set(ob, 140, -1);
+   e_widget_entry_readonly_set(ob, 1);
+   e_widget_table_object_append(ot, ob, 1, 2, 1, 1, 1, 0, 1, 0);
+
+   ob = e_widget_label_add(evas, _(File Type:));
+   e_widget_table_object_append(ot, ob, 0, 3, 1, 1, 1, 0, 1, 0);
+   ob = e_widget_entry_add(evas, (cfdata-mime));
+   e_widget_min_size_set(ob, 140, -1);
+   e_widget_entry_readonly_set(ob, 1);
+   e_widget_table_object_append(ot, ob, 1, 3, 1, 1, 1, 0, 1, 0);
+
+   of = e_widget_framelist_add(evas, _(Permissions), 0);
+   ob = e_widget_check_add(evas, _(Others can read), (cfdata-others_read));
+   e_widget_framelist_object_append(of, ob);
+   ob = e_widget_check_add(evas, _(Others can write), 
(cfdata-others_write));
+   e_widget_framelist_object_append(of, ob);
+   
@@ -6,20 +6,20 @@
  * 
  * basic -
- * * show file
- * * show size
- * * show modified date
- * * show permissions
- * * show preview
+ * + show file 
+ * + show size
+ * + show modified date
+ * + show mimetype
+ * + show permissions (others read, others write)
+ * + show preview
  * * show icon
  * * show symlink/fifo/socket/etc. status

E CVS: libs/ewl ningerso

2006-12-05 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : ningerso
Project : e17
Module  : libs/ewl

Dir : e17/libs/ewl/src/bin/tests/text


Modified Files:
ewl_text.c 


Log Message:
Remove debugging return 1;

===
RCS file: /cvs/e/e17/libs/ewl/src/bin/tests/text/ewl_text.c,v
retrieving revision 1.4
retrieving revision 1.5